============
Installation
============

Django-snitch can be installed from PyPI with tools like ``pip``:

.. code-block:: bash

    $ pip install django-snitch

Then add ``"snitch"`` to your ``INSTALLED_APPS``.

.. code-block:: python

    INSTALLED_APPS = [
        ...
        "snitch",
    ]
